@@ -19,22 +19,27 @@
 
 #include "komparemodellist.h"
 
+#include <QAction>
 #include <QtCore/QFile>
 #include <QtCore/QDir>
 #include <QtCore/QRegExp>
 #include <QtCore/QTextCodec>
 #include <QtCore/QTextStream>
 #include <QtCore/QLinkedList>
+#include <QtCore/QTemporaryFile>
+#include <QLoggingCategory>
 
-#include <kaction.h>
 #include <kactioncollection.h>
 #include <kcharsets.h>
-#include <kdebug.h>
 #include <kdirwatch.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
-#include <kmimetype.h>
-#include <ktemporaryfile.h>
+#include <kio/udsentry.h>
+#include <kio/statjob.h>
+#include <kio/mkdirjob.h>
+#include <kio/filecopyjob.h>
+#define TRANSLATION_DOMAIN "libkomparediff2"
+#include <klocalizedstring.h>
+#include <QMimeType>
+#include <QMimeDatabase>
 #include <kstandardaction.h>
 
 #include "difference.h"
@@ -43,9 +48,9 @@
 #include "diffmodellist.h"
 #include "kompareprocess.h"
 #include "parser.h"
-#include <kglobal.h>
 
-static const KCatalogLoader loader("libkomparediff2");
+Q_DECLARE_LOGGING_CATEGORY(LIBKOMPAREDIFF2)
+Q_LOGGING_CATEGORY(LIBKOMPAREDIFF2, "libkomparediff")
 
 using namespace Diff2;
 
@@ -62,40 +67,40 @@ KompareModelList::KompareModelList( DiffSettings* diffSettings, QWidget* widgetF
 	m_widgetForKIO( widgetForKIO ),
 	m_isReadWrite( isReadWrite )
 {
-	kDebug(8101) << "Show me the arguments: " << diffSettings << ", " << widgetForKIO << ", " << parent << ", " << name << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Show me the arguments: " << diffSettings << ", " << widgetForKIO << ", " << parent << ", " << name;
 	m_actionCollection = new KActionCollection(this);
 	m_applyDifference = m_actionCollection->addAction( "difference_apply", this, SLOT(slotActionApplyDifference()) );
-	m_applyDifference->setIcon( KIcon("arrow-right") );
+	m_applyDifference->setIcon( QIcon::fromTheme("arrow-right") );
 	m_applyDifference->setText( i18n("&Apply Difference") );
-	m_applyDifference->setShortcut( QKeySequence(Qt::Key_Space) );
+	m_actionCollection->setDefaultShortcut( m_applyDifference, QKeySequence(Qt::Key_Space) );
 	m_unApplyDifference = m_actionCollection->addAction( "difference_unapply", this, SLOT(slotActionUnApplyDifference()) );
-	m_unApplyDifference->setIcon( KIcon("arrow-left") );
+	m_unApplyDifference->setIcon( QIcon::fromTheme("arrow-left") );
 	m_unApplyDifference->setText( i18n("Un&apply Difference") );
-	m_unApplyDifference->setShortcut( QKeySequence(Qt::Key_Backspace) );
+	m_actionCollection->setDefaultShortcut( m_unApplyDifference, QKeySequence(Qt::Key_Backspace) );
 	m_applyAll = m_actionCollection->addAction( "difference_applyall", this, SLOT(slotActionApplyAllDifferences()) );
-	m_applyAll->setIcon( KIcon("arrow-right-double") );
+	m_applyAll->setIcon( QIcon::fromTheme("arrow-right-double") );
 	m_applyAll->setText( i18n("App&ly All") );
-	m_applyAll->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_A) );
+	m_actionCollection->setDefaultShortcut( m_applyAll, QKeySequence(Qt::CTRL + Qt::Key_A) );
 	m_unapplyAll = m_actionCollection->addAction( "difference_unapplyall", this, SLOT(slotActionUnapplyAllDifferences()) );
-	m_unapplyAll->setIcon( KIcon("arrow-left-double") );
+	m_unapplyAll->setIcon( QIcon::fromTheme("arrow-left-double") );
 	m_unapplyAll->setText( i18n("&Unapply All") );
-	m_unapplyAll->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_U) );
+	m_actionCollection->setDefaultShortcut( m_unapplyAll, QKeySequence(Qt::CTRL + Qt::Key_U) );
 	m_previousFile = m_actionCollection->addAction( "difference_previousfile", this, SLOT(slotPreviousModel()) );
-	m_previousFile->setIcon( KIcon("arrow-up-double") );
+	m_previousFile->setIcon( QIcon::fromTheme("arrow-up-double") );
 	m_previousFile->setText( i18n("P&revious File") );
-	m_previousFile->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_PageUp) );
+	m_actionCollection->setDefaultShortcut( m_previousFile, QKeySequence(Qt::CTRL + Qt::Key_PageUp) );
 	m_nextFile = m_actionCollection->addAction( "difference_nextfile", this, SLOT(slotNextModel()) );
-	m_nextFile->setIcon( KIcon("arrow-down-double") );
+	m_nextFile->setIcon( QIcon::fromTheme("arrow-down-double") );
 	m_nextFile->setText( i18n("N&ext File") );
-	m_nextFile->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_PageDown) );
+	m_actionCollection->setDefaultShortcut( m_nextFile, QKeySequence(Qt::CTRL + Qt::Key_PageDown) );
 	m_previousDifference = m_actionCollection->addAction( "difference_previous", this, SLOT(slotPreviousDifference()) );
-	m_previousDifference->setIcon( KIcon("arrow-up") );
+	m_previousDifference->setIcon( QIcon::fromTheme("arrow-up") );
 	m_previousDifference->setText( i18n("&Previous Difference") );
-	m_previousDifference->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_Up) );
+	m_actionCollection->setDefaultShortcut( m_previousDifference, QKeySequence(Qt::CTRL + Qt::Key_Up) );
 	m_nextDifference = m_actionCollection->addAction( "difference_next", this, SLOT(slotNextDifference()) );
-	m_nextDifference->setIcon( KIcon("arrow-down") );
+	m_nextDifference->setIcon( QIcon::fromTheme("arrow-down") );
 	m_nextDifference->setText( i18n("&Next Difference") );
-	m_nextDifference->setShortcut( QKeySequence(Qt::CTRL + Qt::Key_Down) );
+	m_actionCollection->setDefaultShortcut( m_nextDifference, QKeySequence(Qt::CTRL + Qt::Key_Down) );
 	m_previousDifference->setEnabled( false );
 	m_nextDifference->setEnabled( false );
 
@@ -146,26 +151,27 @@ bool KompareModelList::compare()
 	{
 		QFile sourceFile( m_info->localSource );
 		sourceFile.open( QIODevice::ReadOnly );
-		QString sourceMimeType = ( KMimeType::findByContent( sourceFile.readAll() ) )->name();
+		QMimeDatabase db;
+		QString sourceMimeType = ( db.mimeTypeForData( sourceFile.readAll() ) ).name();
 		sourceFile.close();
-		kDebug(8101) << "Mimetype source     : " << sourceMimeType << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Mimetype source     : " << sourceMimeType;
 
 		QFile destinationFile( m_info->localDestination );
 		destinationFile.open( QIODevice::ReadOnly );
-		QString destinationMimeType = ( KMimeType::findByContent( destinationFile.readAll() ) )->name();
+		QString destinationMimeType = ( db.mimeTypeForData( destinationFile.readAll() ) ).name();
 		destinationFile.close();
-		kDebug(8101) << "Mimetype destination: " << destinationMimeType << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Mimetype destination: " << destinationMimeType;
 
 		// Not checking if it is a text file/something diff can even compare, we'll let diff handle that
 		if ( !isDiff( sourceMimeType ) && isDiff( destinationMimeType ) )
 		{
-			kDebug(8101) << "Blending destination into source..." << endl;
+			qCDebug(LIBKOMPAREDIFF2) << "Blending destination into source...";
 			m_info->mode = Kompare::BlendingFile;
 			result = openFileAndDiff();
 		}
 		else if ( isDiff( sourceMimeType ) && !isDiff( destinationMimeType ) )
 		{
-			kDebug(8101) << "Blending source into destination..." << endl;
+			qCDebug(LIBKOMPAREDIFF2) << "Blending source into destination...";
 			m_info->mode = Kompare::BlendingFile;
 			// Swap source and destination before calling this
 			m_info->swapSourceWithDestination();
@@ -175,7 +181,7 @@ bool KompareModelList::compare()
 		}
 		else
 		{
-			kDebug(8101) << "Comparing source with destination" << endl;
+			qCDebug(LIBKOMPAREDIFF2) << "Comparing source with destination";
 			m_info->mode = Kompare::ComparingFiles;
 			result = compare(m_info->mode);
 		}
@@ -261,7 +267,7 @@ bool KompareModelList::openFileAndDiff()
 
 	if ( !blendOriginalIntoModelList( m_info->localSource ) )
 	{
-		kDebug(8101) << "Oops cant blend original file into modellist : " << m_info->localSource << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Oops cant blend original file into modellist : " << m_info->localSource;
 		emit( i18n( "<qt>There were problems applying the diff <b>%1</b> to the file <b>%2</b>.</qt>", m_info->destination.url(), m_info->source.url() ) );
 		return false;
 	}
@@ -288,7 +294,7 @@ bool KompareModelList::openDirAndDiff()
 	if ( !blendOriginalIntoModelList( m_info->localSource ) )
 	{
 		// Trouble blending the original into the model
-		kDebug(8101) << "Oops cant blend original dir into modellist : " << m_info->localSource << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Oops cant blend original dir into modellist : " << m_info->localSource;
 		emit error( i18n( "<qt>There were problems applying the diff <b>%1</b> to the folder <b>%2</b>.</qt>", m_info->destination.url(), m_info->source.url() ) );
 		return false;
 	}
@@ -312,14 +318,14 @@ void KompareModelList::slotSaveDestination()
 
 bool KompareModelList::saveDestination( DiffModel* model )
 {
-	kDebug(8101) << "KompareModelList::saveDestination: " << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::saveDestination: ";
 
 	// Unecessary safety check, we can guarantee there are unsaved changes!!!
 	if( !model->hasUnsavedChanges() )
 		return true;
 
-	KTemporaryFile temp;
-	
+	QTemporaryFile temp;
+
 	if( !temp.open() ) {
 		emit error( i18n( "Could not open a temporary file." ) );
 		temp.remove();
@@ -364,7 +370,7 @@ bool KompareModelList::saveDestination( DiffModel* model )
 		}
 	}
 
-	// kDebug(8101) << "Everything: " << endl << list.join( "\n" ) << endl;
+	// qCDebug(LIBKOMPAREDIFF2) << "Everything: " << endl << list.join( "\n" );
 
 	if( list.count() > 0 )
 		stream << list.join( "" );
@@ -388,42 +394,47 @@ bool KompareModelList::saveDestination( DiffModel* model )
 	{
 		// Dont use destination which was used for creating the diff directly, use the original URL!!!
 		// FIXME!!! Wrong destination this way! Need to add the sub directory to the url!!!!
-		kDebug(8101) << "Tempfilename (save) : " << temp.fileName() << endl;
-		kDebug(8101) << "Model->path+file    : " << model->destinationPath() << model->destinationFile() << endl;
-		kDebug(8101) << "info->localdest     : " << m_info->localDestination << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Tempfilename (save) : " << temp.fileName();
+		qCDebug(LIBKOMPAREDIFF2) << "Model->path+file    : " << model->destinationPath() << model->destinationFile();
+		qCDebug(LIBKOMPAREDIFF2) << "info->localdest     : " << m_info->localDestination;
 		QString tmp = model->destinationPath() + model->destinationFile();
 		if ( tmp.startsWith( m_info->localDestination ) ) // It should, if not serious trouble...
 			tmp.remove( 0, m_info->localDestination.size() );
-		kDebug(8101) << "DestinationURL      : " << m_info->destination << endl;
-		kDebug(8101) << "tmp                 : " << tmp << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "DestinationURL      : " << m_info->destination;
+		qCDebug(LIBKOMPAREDIFF2) << "tmp                 : " << tmp;
 		KIO::UDSEntry entry;
-		KUrl fullDestinationPath( m_info->destination );
-		fullDestinationPath.addPath( tmp );
-		kDebug(8101) << "fullDestinationPath : " << fullDestinationPath << endl;
-		if ( !KIO::NetAccess::stat( fullDestinationPath.directory(), entry, m_widgetForKIO ) )
+		QUrl fullDestinationPath = m_info->destination;
+		fullDestinationPath.setPath( fullDestinationPath.path() + "/" + tmp );
+		qCDebug(LIBKOMPAREDIFF2) << "fullDestinationPath : " << fullDestinationPath;
+		KIO::StatJob *statJob = KIO::stat( fullDestinationPath.path() );
+		if ( !statJob->exec() )
 		{
-			if ( !KIO::NetAccess::mkdir( fullDestinationPath.directory(), m_widgetForKIO ) )
+			entry = statJob->statResult();
+			KIO::MkdirJob* mkdirJob = KIO::mkdir( fullDestinationPath.path() );
+			if ( !mkdirJob->exec() )
 			{
-				emit error( i18n( "<qt>Could not create destination directory <b>%1</b>.\nThe file has not been saved.</qt>", fullDestinationPath.directory() ) );
+				emit error( i18n( "<qt>Could not create destination directory <b>%1</b>.\nThe file has not been saved.</qt>", fullDestinationPath.path() ) );
 				return false;
 			}
 		}
-		result = KIO::NetAccess::upload( temp.fileName(), fullDestinationPath, m_widgetForKIO );
+		KIO::FileCopyJob* copyJob = KIO::file_copy( QUrl::fromLocalFile( temp.fileName() ), fullDestinationPath, -1, KIO::Overwrite);
+		result = copyJob->exec();
 	}
 	else
 	{
-		kDebug(8101) << "Tempfilename   : " << temp.fileName() << endl;
-		kDebug(8101) << "DestinationURL : " << m_info->destination << endl;
-		result = KIO::NetAccess::upload( temp.fileName(), m_info->destination, m_widgetForKIO );
-		kDebug(8101) << "true or false?" << result << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Tempfilename   : " << temp.fileName();
+		qCDebug(LIBKOMPAREDIFF2) << "DestinationURL : " << m_info->destination;
+		KIO::FileCopyJob* copyJob = KIO::file_copy( QUrl::fromLocalFile( temp.fileName() ), m_info->destination , -1, KIO::Overwrite);
+		result = copyJob->exec();
+		qCDebug(LIBKOMPAREDIFF2) << "true or false?" << result;
 	}
 
 	if ( !result )
 	{
 		// FIXME: Wrong first argument given in case of comparing directories!
 		emit error( i18n( "<qt>Could not upload the temporary file to the destination location <b>%1</b>. The temporary file is still available under: <b>%2</b>. You can manually copy it to the right place.</qt>", m_info->destination.url(), temp.fileName() ) );
-                //Don't remove file when we delete temp and don't leak it.
-                temp.setAutoRemove(false);
+		//Don't remove file when we delete temp and don't leak it.
+		temp.setAutoRemove(false);
 	}
 	else
 	{
@@ -470,13 +481,13 @@ void KompareModelList::setEncoding( const QString& encoding )
 	}
 	else
 	{
-		kDebug(8101) << "Encoding : " << encoding << endl;
-		m_textCodec = KGlobal::charsets()->codecForName( encoding.toLatin1() );
-		kDebug(8101) << "TextCodec: " << m_textCodec << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Encoding : " << encoding;
+		m_textCodec = KCharsets::charsets()->codecForName( encoding.toLatin1() );
+		qCDebug(LIBKOMPAREDIFF2) << "TextCodec: " << m_textCodec;
 		if ( !m_textCodec )
 			m_textCodec = QTextCodec::codecForLocale();
 	}
-	kDebug(8101) << "TextCodec: " << m_textCodec << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "TextCodec: " << m_textCodec;
 }
 
 void KompareModelList::slotDiffProcessFinished( bool success )
@@ -492,7 +503,7 @@ void KompareModelList::slotDiffProcessFinished( bool success )
 		{
 			if ( m_info->mode != Kompare::ShowingDiff )
 			{
-				kDebug(8101) << "Blend this crap please and do not give me any conflicts..." << endl;
+				qCDebug(LIBKOMPAREDIFF2) << "Blend this crap please and do not give me any conflicts...";
 				blendOriginalIntoModelList( m_info->localSource );
 			}
 			updateModelListActions();
@@ -516,7 +527,7 @@ void KompareModelList::slotDiffProcessFinished( bool success )
 void KompareModelList::slotDirectoryChanged( const QString& /*dir*/ )
 {
 	// some debug output to see if watching works properly
-	kDebug(8101) << "Yippie directories are being watched !!! :)" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Yippie directories are being watched !!! :)";
 	if ( m_diffProcess )
 	{
 		emit status( Kompare::ReRunningDiff );
@@ -527,7 +538,7 @@ void KompareModelList::slotDirectoryChanged( const QString& /*dir*/ )
 void KompareModelList::slotFileChanged( const QString& /*file*/ )
 {
 	// some debug output to see if watching works properly
-	kDebug(8101) << "Yippie files are being watched !!! :)" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Yippie files are being watched !!! :)";
 	if ( m_diffProcess )
 	{
 		emit status( Kompare::ReRunningDiff );
@@ -570,7 +581,7 @@ QString KompareModelList::readFile( const QString& fileName )
 	file.open( QIODevice::ReadOnly );
 
 	QTextStream stream( &file );
-	kDebug(8101) << "Codec = " << m_textCodec << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Codec = " << m_textCodec;
 
 	if (  !m_textCodec )
 		m_textCodec = QTextCodec::codecForLocale();
@@ -586,7 +597,7 @@ QString KompareModelList::readFile( const QString& fileName )
 
 bool KompareModelList::openDiff( const QString& diffFile )
 {
-	kDebug(8101) << "Stupid :) Url = " << diffFile << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Stupid :) Url = " << diffFile;
 
 	if ( diffFile.isEmpty() )
 		return false;
@@ -646,9 +657,9 @@ QString KompareModelList::recreateDiff() const
 
 bool KompareModelList::saveDiff( const QString& url, QString directory, DiffSettings* diffSettings )
 {
-	kDebug(8101) << "KompareModelList::saveDiff: " << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::saveDiff: ";
 
-	m_diffTemp = new KTemporaryFile();
+	m_diffTemp = new QTemporaryFile();
 	m_diffURL = url;
 
 	if( !m_diffTemp->open() ) {
@@ -672,7 +683,7 @@ bool KompareModelList::saveDiff( const QString& url, QString directory, DiffSett
 
 void KompareModelList::slotWriteDiffOutput( bool success )
 {
-	kDebug(8101) << "Success = " << success << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Success = " << success;
 
 	if( success )
 	{
@@ -687,7 +698,8 @@ void KompareModelList::slotWriteDiffOutput( bool success )
 			emit error( i18n( "Could not write to the temporary file." ) );
 		}
 
-		KIO::NetAccess::upload( m_diffTemp->fileName(), KUrl( m_diffURL ), m_widgetForKIO );
+		KIO::FileCopyJob* copyJob = KIO::file_copy( QUrl::fromLocalFile( m_diffTemp->fileName() ), m_diffURL );
+		copyJob->exec();
 
 		emit status( Kompare::FinishedWritingDiff );
 	}
@@ -706,13 +718,13 @@ void KompareModelList::slotSelectionChanged( const Diff2::DiffModel* model, cons
 {
 // This method will signal all the other objects about a change in selection,
 // it will emit setSelection( const DiffModel*, const Difference* ) to all who are connected
-	kDebug(8101) << "KompareModelList::slotSelectionChanged( " << model << ", " << diff << " )" << endl;
-	kDebug(8101) << "Sender is : " << sender()->metaObject()->className() << endl;
-//	kDebug(8101) << kBacktrace() << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::slotSelectionChanged( " << model << ", " << diff << " )";
+	qCDebug(LIBKOMPAREDIFF2) << "Sender is : " << sender()->metaObject()->className();
+//	qCDebug(LIBKOMPAREDIFF2) << kBacktrace();
 
 	m_selectedModel = const_cast<DiffModel*>(model);
 	m_modelIndex = m_models->indexOf( m_selectedModel );
-	kDebug(8101) << "m_modelIndex = " << m_modelIndex << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "m_modelIndex = " << m_modelIndex;
 	m_selectedDifference = const_cast<Difference*>(diff);
 
 	m_selectedModel->setSelectedDifference( m_selectedDifference );
@@ -741,8 +753,8 @@ void KompareModelList::slotSelectionChanged( const Diff2::Difference* diff )
 {
 // This method will emit setSelection( const Difference* ) to whomever is listening
 // when for instance in kompareview the selection has changed
-	kDebug(8101) << "KompareModelList::slotSelectionChanged( " << diff << " )" << endl;
-	kDebug(8101) << "Sender is : " << sender()->metaObject()->className() << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::slotSelectionChanged( " << diff << " )";
+	qCDebug(LIBKOMPAREDIFF2) << "Sender is : " << sender()->metaObject()->className();
 
 	m_selectedDifference = const_cast<Difference*>(diff);
 
@@ -794,9 +806,9 @@ void KompareModelList::slotNextModel()
 
 DiffModel* KompareModelList::firstModel()
 {
-	kDebug(8101) << "KompareModelList::firstModel()" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::firstModel()";
 	m_modelIndex = 0;
-	kDebug(8101) << "m_modelIndex = " << m_modelIndex << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "m_modelIndex = " << m_modelIndex;
 
 	m_selectedModel = m_models->first();
 
@@ -805,9 +817,9 @@ DiffModel* KompareModelList::firstModel()
 
 DiffModel* KompareModelList::lastModel()
 {
-	kDebug(8101) << "KompareModelList::lastModel()" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::lastModel()";
 	m_modelIndex = m_models->count() - 1;
-	kDebug(8101) << "m_modelIndex = " << m_modelIndex << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "m_modelIndex = " << m_modelIndex;
 
 	m_selectedModel = m_models->last();
 
@@ -816,17 +828,17 @@ DiffModel* KompareModelList::lastModel()
 
 DiffModel* KompareModelList::prevModel()
 {
-	kDebug(8101) << "KompareModelList::prevModel()" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::prevModel()";
 	if ( m_modelIndex > 0 && --m_modelIndex < m_models->count() )
 	{
-		kDebug(8101) << "m_modelIndex = " << m_modelIndex << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "m_modelIndex = " << m_modelIndex;
 		m_selectedModel = (*m_models)[ m_modelIndex ];
 	}
 	else
 	{
 		m_selectedModel = 0;
 		m_modelIndex = 0;
-		kDebug(8101) << "m_modelIndex = " << m_modelIndex << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "m_modelIndex = " << m_modelIndex;
 	}
 
 	return m_selectedModel;
@@ -834,17 +846,17 @@ DiffModel* KompareModelList::prevModel()
 
 DiffModel* KompareModelList::nextModel()
 {
-	kDebug(8101) << "KompareModelList::nextModel()" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::nextModel()";
 	if ( ++m_modelIndex < m_models->count() )
 	{
-		kDebug(8101) << "m_modelIndex = " << m_modelIndex << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "m_modelIndex = " << m_modelIndex;
 		m_selectedModel = (*m_models)[ m_modelIndex ];
 	}
 	else
 	{
 		m_selectedModel = 0;
 		m_modelIndex = 0;
-		kDebug(8101) << "m_modelIndex = " << m_modelIndex << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "m_modelIndex = " << m_modelIndex;
 	}
 
 	return m_selectedModel;
@@ -857,7 +869,7 @@ KActionCollection* KompareModelList::actionCollection() const
 
 void KompareModelList::slotPreviousDifference()
 {
-	kDebug(8101) << "slotPreviousDifference called" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "slotPreviousDifference called";
 	if ( ( m_selectedDifference = m_selectedModel->prevDifference() ) != 0 )
 	{
 		emit setSelection( m_selectedDifference );
@@ -866,7 +878,7 @@ void KompareModelList::slotPreviousDifference()
 		return;
 	}
 
-	kDebug(8101) << "**** no previous difference... ok lets find the previous model..." << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "**** no previous difference... ok lets find the previous model...";
 
 	if ( ( m_selectedModel = prevModel() ) != 0 )
 	{
@@ -879,7 +891,7 @@ void KompareModelList::slotPreviousDifference()
 	}
 
 
-	kDebug(8101) << "**** !!! No previous model, ok backup plan activated..." << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "**** !!! No previous model, ok backup plan activated...";
 
 	// Backup plan
 	m_selectedModel = firstModel();
@@ -892,7 +904,7 @@ void KompareModelList::slotPreviousDifference()
 
 void KompareModelList::slotNextDifference()
 {
-	kDebug(8101) << "slotNextDifference called" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "slotNextDifference called";
 	if ( ( m_selectedDifference = m_selectedModel->nextDifference() ) != 0 )
 	{
 		emit setSelection( m_selectedDifference );
@@ -901,7 +913,7 @@ void KompareModelList::slotNextDifference()
 		return;
 	}
 
-	kDebug(8101) << "**** no next difference... ok lets find the next model..." << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "**** no next difference... ok lets find the next model...";
 
 	if ( ( m_selectedModel = nextModel() ) != 0 )
 	{
@@ -913,7 +925,7 @@ void KompareModelList::slotNextDifference()
 		return;
 	}
 
-	kDebug(8101) << "**** !!! No next model, ok backup plan activated..." << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "**** !!! No next model, ok backup plan activated...";
 
 	// Backup plan
 	m_selectedModel = lastModel();
@@ -938,7 +950,7 @@ void KompareModelList::slotApplyAllDifferences( bool apply )
 
 int KompareModelList::parseDiffOutput( const QString& diff )
 {
-	kDebug(8101) << "KompareModelList::parseDiffOutput" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::parseDiffOutput";
 	emit diffString( diff );
 
 	QStringList diffLines = split( diff );
@@ -956,19 +968,19 @@ int KompareModelList::parseDiffOutput( const QString& diff )
 	{
 		if ( malformed )
 		{
-			kDebug(8101) << "Malformed diff" << endl;
+			qCDebug(LIBKOMPAREDIFF2) << "Malformed diff";
 			emit error( i18n( "The diff is malformed. Some lines could not be parsed and will not be displayed in the diff view." ) );
 			// proceed anyway with the lines which have been parsed
 		}
 		m_selectedModel = firstModel();
-		kDebug(8101) << "Ok there are differences..." << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Ok there are differences...";
 		m_selectedDifference = m_selectedModel->firstDifference();
 		emit setStatusBarModelInfo( 0, 0, modelCount(), differenceCount(), 0);
 	}
 	else
 	{
 		// Wow trouble, no models, so no differences...
-		kDebug(8101) << "Now i'll be damned, there should be models here !!!" << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Now i'll be damned, there should be models here !!!";
 		return -1;
 	}
 
@@ -977,7 +989,7 @@ int KompareModelList::parseDiffOutput( const QString& diff )
 
 bool KompareModelList::blendOriginalIntoModelList( const QString& localURL )
 {
-	kDebug(8101) << "Hurrah we are blending..." << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Hurrah we are blending...";
 	QFileInfo fi( localURL );
 
 	bool result = false;
@@ -987,42 +999,42 @@ bool KompareModelList::blendOriginalIntoModelList( const QString& localURL )
 
 	if ( fi.isDir() )
 	{ // is a dir
-		kDebug(8101) << "Blend Dir" << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Blend Dir";
 //		QDir dir( localURL, QString(), QDir::Name|QDir::DirsFirst, QDir::TypeMask );
 		DiffModelListIterator modelIt = m_models->begin();
 		DiffModelListIterator mEnd    = m_models->end();
 		for ( ; modelIt != mEnd; ++modelIt )
 		{
 			model = *modelIt;
-			kDebug(8101) << "Model : " << model << endl;
+			qCDebug(LIBKOMPAREDIFF2) << "Model : " << model;
 			QString filename = model->source();
 			if ( !filename.startsWith( localURL ) )
 				filename = QDir(localURL).filePath(filename);
 			QFileInfo fi2( filename );
 			if ( fi2.exists() )
 			{
-				kDebug(8101) << "Reading from: " << filename << endl;
+				qCDebug(LIBKOMPAREDIFF2) << "Reading from: " << filename;
 				fileContents = readFile( filename );
 				result = blendFile( model, fileContents );
 			}
 			else
 			{
-				kDebug(8101) << "File " << filename << " does not exist !" << endl;
-				kDebug(8101) << "Assume empty file !" << endl;
+				qCDebug(LIBKOMPAREDIFF2) << "File " << filename << " does not exist !";
+				qCDebug(LIBKOMPAREDIFF2) << "Assume empty file !";
 				fileContents.truncate( 0 );
 				result = blendFile( model, fileContents );
 			}
 		}
-		kDebug(8101) << "End of Blend Dir" << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "End of Blend Dir";
 	}
 	else if ( fi.isFile() )
 	{ // is a file
-		kDebug(8101) << "Blend File" << endl;
-		kDebug(8101) << "Reading from: " << localURL << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Blend File";
+		qCDebug(LIBKOMPAREDIFF2) << "Reading from: " << localURL;
 		fileContents = readFile( localURL );
 
 		result = blendFile( (*m_models)[ 0 ], fileContents );
-		kDebug(8101) << "End of Blend File" << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "End of Blend File";
 	}
 
 	return result;
@@ -1032,7 +1044,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 {
 	if ( !model )
 	{
-		kDebug(8101) << "**** model is null :(" << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "**** model is null :(";
 		return false;
 	}
 
@@ -1050,7 +1062,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 	QLinkedList<QString>::ConstIterator lEnd    = lines.end();
 
 	DiffHunkList* hunks = model->hunks();
-	kDebug(8101) << "Hunks in hunklist: " << hunks->count() << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Hunks in hunklist: " << hunks->count();
 	DiffHunkListIterator hunkIt = hunks->begin();
 
 	DiffHunk*   newHunk = 0;
@@ -1119,7 +1131,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 		DifferenceList hunkDiffList   = (*hunkIt)->differences();
 		DifferenceListIterator diffIt = hunkDiffList.begin();
 		DifferenceListIterator dEnd   = hunkDiffList.end();
-		kDebug(8101) << "Number of differences in hunkDiffList = " << diffList.count() << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "Number of differences in hunkDiffList = " << diffList.count();
 
 		DifferenceListIterator tempIt;
 		Difference* diff;
@@ -1127,7 +1139,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 		for ( ; diffIt != dEnd; ++diffIt )
 		{
 			diff = *diffIt;
-			kDebug(8101) << "*(Diff it) = " << diff << endl;
+			qCDebug(LIBKOMPAREDIFF2) << "*(Diff it) = " << diff;
 			// Check if there are lines in the original file before the difference
 			// that are not yet in the diff. If so create new Unchanged diff
 			if ( srcLineNo < diff->sourceLineNumber() )
@@ -1137,7 +1149,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 				newHunk->add( newDiff );
 				while ( srcLineNo < diff->sourceLineNumber() && linesIt != lEnd )
 				{
-//					kDebug(8101) << "SourceLine = " << srcLineNo << ": " << *linesIt << endl;
+//					qCDebug(LIBKOMPAREDIFF2) << "SourceLine = " << srcLineNo << ": " << *linesIt;
 					newDiff->addSourceLine( *linesIt );
 					newDiff->addDestinationLine( *linesIt );
 					srcLineNo++;
@@ -1149,20 +1161,20 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 			switch ( diff->type() )
 			{
 			case Difference::Unchanged:
-				kDebug(8101) << "Unchanged" << endl;
+				qCDebug(LIBKOMPAREDIFF2) << "Unchanged";
 				for ( int i = 0; i < diff->sourceLineCount(); i++ )
 				{
 					if ( linesIt != lEnd && *linesIt != diff->sourceLineAt( i )->string() )
 					{
-						kDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt << endl;
-						kDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+						qCDebug(LIBKOMPAREDIFF2) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt;
+						qCDebug(LIBKOMPAREDIFF2) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string();
 
 						// Do conflict resolution (well sort of)
 						diff->sourceLineAt( i )->setConflictString( *linesIt );
 						diff->setConflict( true );
 					}
-//					kDebug(8101) << "SourceLine = " << srcLineNo << ": " << *linesIt << endl;
-//					kDebug(8101) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+//					qCDebug(LIBKOMPAREDIFF2) << "SourceLine = " << srcLineNo << ": " << *linesIt;
+//					qCDebug(LIBKOMPAREDIFF2) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string();
 					srcLineNo++;
 					destLineNo++;
 					++linesIt;
@@ -1175,7 +1187,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 
 				break;
 			case Difference::Change:
-				kDebug(8101) << "Change" << endl;
+				qCDebug(LIBKOMPAREDIFF2) << "Change";
 
 				//QStringListConstIterator saveIt = linesIt;
 
@@ -1183,8 +1195,8 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 				{
 					if ( linesIt != lEnd && *linesIt != diff->sourceLineAt( i )->string() )
 					{
-						kDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt << endl;
-						kDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+						qCDebug(LIBKOMPAREDIFF2) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt;
+						qCDebug(LIBKOMPAREDIFF2) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string();
 
 						// Do conflict resolution (well sort of)
 						diff->sourceLineAt( i )->setConflictString( *linesIt );
@@ -1205,7 +1217,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 
 				break;
 			case Difference::Insert:
-				kDebug(8101) << "Insert" << endl;
+				qCDebug(LIBKOMPAREDIFF2) << "Insert";
 				destLineNo += diff->destinationLineCount();
 				tempIt = diffIt;
 				--diffIt;
@@ -1214,22 +1226,22 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 				newModel->addDiff( diff );
 				break;
 			case Difference::Delete:
-				kDebug(8101) << "Delete" << endl;
-				kDebug(8101) << "Number of lines in Delete: " << diff->sourceLineCount() << endl;
+				qCDebug(LIBKOMPAREDIFF2) << "Delete";
+				qCDebug(LIBKOMPAREDIFF2) << "Number of lines in Delete: " << diff->sourceLineCount();
 				for ( int i = 0; i < diff->sourceLineCount(); i++ )
 				{
 					if ( linesIt != lEnd && *linesIt != diff->sourceLineAt( i )->string() )
 					{
-						kDebug(8101) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt << endl;
-						kDebug(8101) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+						qCDebug(LIBKOMPAREDIFF2) << "Conflict: SourceLine = " << srcLineNo << ": " << *linesIt;
+						qCDebug(LIBKOMPAREDIFF2) << "Conflict: DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string();
 
 						// Do conflict resolution (well sort of)
 						diff->sourceLineAt( i )->setConflictString( *linesIt );
 						diff->setConflict( true );
 					}
 
-//					kDebug(8101) << "SourceLine = " << srcLineNo << ": " << *it << endl;
-//					kDebug(8101) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string() << endl;
+//					qCDebug(LIBKOMPAREDIFF2) << "SourceLine = " << srcLineNo << ": " << *it;
+//					qCDebug(LIBKOMPAREDIFF2) << "DiffLine   = " << diff->sourceLineNumber() + i << ": " << diff->sourceLineAt( i )->string();
 					srcLineNo++;
 					++linesIt;
 				}
@@ -1241,7 +1253,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 				newModel->addDiff( diff );
 				break;
 			default:
-				kDebug(8101) << "****, some diff type we do not know about ???" << endl;
+				qCDebug(LIBKOMPAREDIFF2) << "****, some diff type we do not know about ???";
 			}
 		}
 	}
@@ -1251,10 +1263,10 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 	diffList = newModel->differences();
 
 	diff = diffList.first();
-	kDebug(8101) << "Count = " << diffList.count() << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "Count = " << diffList.count();
 	for ( diff = diffList.first(); diff; diff = diffList.next() )
 	{
-		kDebug(8101) << "sourcelinenumber = " << diff->sourceLineNumber() << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "sourcelinenumber = " << diff->sourceLineNumber();
 	}
 */
 
@@ -1267,7 +1279,7 @@ bool KompareModelList::blendFile( DiffModel* model, const QString& fileContents
 
 void KompareModelList::show()
 {
-	kDebug(8101) << "KompareModelList::Show Number of models = " << m_models->count() << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::Show Number of models = " << m_models->count();
 	emit modelsChanged( m_models );
 	emit setSelection( m_selectedModel, m_selectedDifference );
 }
@@ -1333,15 +1345,15 @@ void KompareModelList::slotKompareInfo( struct Kompare::Info* info )
 
 bool KompareModelList::setSelectedModel( DiffModel* model )
 {
-	kDebug(8101) << "KompareModelList::setSelectedModel( " << model << " )" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::setSelectedModel( " << model << " )";
 
 	if ( model != m_selectedModel )
 	{
 		if ( !m_models->contains( model ) )
 			return false;
-		kDebug(8101) << "m_selectedModel (was) = " << m_selectedModel << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "m_selectedModel (was) = " << m_selectedModel;
 		m_modelIndex = m_models->indexOf( model );
-		kDebug(8101) << "m_selectedModel (is)  = " << m_selectedModel << endl;
+		qCDebug(LIBKOMPAREDIFF2) << "m_selectedModel (is)  = " << m_selectedModel;
 		m_selectedModel = model;
 	}
 
@@ -1401,73 +1413,73 @@ void KompareModelList::updateModelListActions()
 
 bool KompareModelList::hasPrevModel() const
 {
-	kDebug(8101) << "KompareModelList::hasPrevModel()" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::hasPrevModel()";
 
 	if (  m_modelIndex > 0 )
 	{
-//		kDebug(8101) << "has prev model" << endl;
+//		qCDebug(LIBKOMPAREDIFF2) << "has prev model";
 		return true;
 	}
 
-//	kDebug(8101) << "doesn't have a prev model, this is the first one..." << endl;
+//	qCDebug(LIBKOMPAREDIFF2) << "doesn't have a prev model, this is the first one...";
 
 	return false;
 }
 
 bool KompareModelList::hasNextModel() const
 {
-	kDebug(8101) << "KompareModelList::hasNextModel()" << endl;
+	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::hasNextModel()";
 
 	if ( m_modelIndex < (  m_models->count() - 1 ) )
 	{
-//		kDebug(8101) << "has next model" << endl;
+//		qCDebug(LIBKOMPAREDIFF2) << "has next model";
 		return true;
 	}
 
-//	kDebug(8101) << "doesn't have a next model, this is the last one..." << endl;
+//	qCDebug(LIBKOMPAREDIFF2) << "doesn't have a next model, this is the last one...";
 	return false;
 }
 
 bool KompareModelList::hasPrevDiff() const
 {
-//	kDebug(8101) << "KompareModelList::hasPrevDiff()" << endl;
+//	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::hasPrevDiff()";
 	int index = m_selectedModel->diffIndex();
 
 	if ( index > 0 )
 	{
-//		kDebug(8101) << "has prev difference in same model" << endl;
+//		qCDebug(LIBKOMPAREDIFF2) << "has prev difference in same model";
 		return true;
 	}
 
 	if ( hasPrevModel() )
 	{
-//		kDebug(8101) << "has prev difference but in prev model" << endl;
+//		qCDebug(LIBKOMPAREDIFF2) << "has prev difference but in prev model";
 		return true;
 	}
 
-//	kDebug(8101) << "doesn't have a prev difference, not even in the previous model because there is no previous model" << endl;
+//	qCDebug(LIBKOMPAREDIFF2) << "doesn't have a prev difference, not even in the previous model because there is no previous model";
 
 	return false;
 }
 
 bool KompareModelList::hasNextDiff() const
 {
-//	kDebug(8101) << "KompareModelList::hasNextDiff()" << endl;
+//	qCDebug(LIBKOMPAREDIFF2) << "KompareModelList::hasNextDiff()";
 	int index = m_selectedModel->diffIndex();
 
 	if ( index < ( m_selectedModel->differenceCount() - 1 ) )
 	{
-//		kDebug(8101) << "has next difference in same model" << endl;
+//		qCDebug(LIBKOMPAREDIFF2) << "has next difference in same model";
 		return true;
 	}
 
 	if ( hasNextModel() )
 	{
-//		kDebug(8101) << "has next difference but in next model" << endl;
+//		qCDebug(LIBKOMPAREDIFF2) << "has next difference but in next model";
 		return true;
 	}
 
-//	kDebug(8101) << "doesn't have a next difference, not even in next model because there is no next model" << endl;
+//	qCDebug(LIBKOMPAREDIFF2) << "doesn't have a next difference, not even in next model because there is no next model";
 
 	return false;
 }
@@ -1500,6 +1512,5 @@ void KompareModelList::slotActionUnapplyAllDifferences()
 	updateModelListActions();
 }
 
-#include "komparemodellist.moc"
 
 /* vim: set ts=4 sw=4 noet: */
